<?php
/* $Id: czech-windows-1250.inc.php,v 2.98.2.1 2005/06/30 17:22:38 lem9 Exp $ */

/**
 * Czech language file by
 *   Michal iha <nijel at users.sourceforge.net>
 */

$charset = 'windows-1250';
$text_dir = 'ltr';
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'tahoma, arial, helvetica, geneva, sans-serif';
$number_thousands_separator = ' ';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('bajt', 'kB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Nedle', 'Pondl', 'ter', 'Steda', 'tvrtek', 'Ptek', 'Sobota');
$month = array('ledna', 'nora', 'bezna', 'dubna', 'kvtna', 'ervna', 'ervence', 'srpna', 'z', 'jna', 'listopadu', 'prosince');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%a %d. %b %Y, %H:%M';

$timespanfmt = '%s dn, %s hodin, %s minut a %s sekund';

$strAbortedClients = 'Peruen';
$strAbsolutePathToDocSqlDir = 'docSQL adres';
$strAccessDeniedExplanation = 'phpMyAdmin se pokusil pipojit k&nbsp;MySQL serveru, a ten odmtl pipojen. Zkontrolujte jmno serveru, uivatelsk jmno a heslo v&nbsp;souboru config.inc.php a ujistte se, e jsou toton s&nbsp;tmi, kter mte od administrtora MySQL serveru.';
$strAccessDenied = 'Pstup odepen';
$strAction = 'Akce';
$strAddAutoIncrement = 'Pidat hodnotu AUTO_INCREMENT';
$strAddConstraints = 'Pidat integritn omezen';
$strAddDeleteColumn = 'Pidat nebo odebrat sloupec';
$strAddDeleteRow = 'Pidat nebo odebrat dek';
$strAddDropDatabase = 'Pidat DROP DATABASE';
$strAddedColumnComment = 'Pidn koment ke sloupci';
$strAddedColumnRelation = 'Pidna relace pro sloupec';
$strAddFields = 'Pidat %s poloek';
$strAddHeaderComment = 'Pidat vlastn koment do hlaviky (\\n oddluje dky)';
$strAddIfNotExists = 'Pidat IF NOT EXISTS';
$strAddIntoComments = 'Do koment pidat';
$strAddNewField = 'Pidat sloupec';
$strAddPrivilegesOnDb = 'Pidat oprvnn pro databzi';
$strAddPrivilegesOnTbl = 'Pidat oprvnn pro tabulku';
$strAddSearchConditions = 'Pidat vyhledvac parametry (st dotazu po pkazu "WHERE"):';
$strAddToIndex = 'Pidat %s sloupc do indexu';
$strAddUserMessage = 'Uivatel byl pidn.';
$strAddUser = 'Pidat novho uivatele';
$strAdministration = 'Sprva';
$strAffectedRows = 'Ovlivnn dky:';
$strAfterInsertBack = 'Nvrat na pedchoz strnku';
$strAfterInsertNewInsert = 'Vloit dal dek';
$strAfterInsertNext = 'Upravit nsledujc dek';
$strAfterInsertSame = 'Nvrat na tuto strnku';
$strAfter = 'Po %s';
$strAllTableSameWidth = 'Pout pro vechny tabulky stejnou ku';
$strAll = 'Vechno';
$strAlterOrderBy = 'Zmnit poad tabulky podle';
$strAnalyzeTable = 'Analyzovat tabulku';
$strAnd = 'a';
$strAnIndex = 'K&nbsp;tabulce %s byl pidn index';
$strAnyHost = 'Jakkoliv pota';
$strAny = 'Jakkoliv';
$strAnyUser = 'Jakkoliv uivatel';
$strApproximateCount = 'Me bt nepesn, viz FAQ 3.11';
$strAPrimaryKey = 'V&nbsp;tabulce %s byl vytvoen primrn kl';
$strArabic = 'Arabtina';
$strArmenian = 'Armntina';
$strAscending = 'Vzestupn';
$strAtBeginningOfTable = 'Na zatku tabulky';
$strAtEndOfTable = 'Na konci tabulky';
$strAttr = 'Vlastnosti';
$strAutodetect = 'Automaticky zjistit';
$strAutomaticLayout = 'automatick rozvren';

$strBack = 'Zpt';
$strBaltic = 'Baltick';
$strBeginCut = 'ZATEK VPISU';
$strBeginRaw = 'ZATEK VPISU';
$strBinary = ' Binrn ';
$strBinaryDoNotEdit = ' Binrn - neupravujte ';
$strBinaryLog = 'Binrn log';
$strBinLogEventType = 'Typ udlosti';
$strBinLogInfo = 'Informace';
$strBinLogName = 'Jmno logu';
$strBinLogOriginalPosition = 'Pvodn pozice';
$strBinLogPosition = 'Pozice';
$strBinLogServerId = 'ID serveru';
$strBookmarkAllUsers = 'Umonit vem uivatelm pouvat tuto poloku';
$strBookmarkDeleted = 'Poloka byla smazna z&nbsp;oblbench.';
$strBookmarkLabel = 'Nzev';
$strBookmarkOptions = 'Nastaven oblbenho dotazu';
$strBookmarkQuery = 'Oblben SQL dotaz';
$strBookmarkThis = 'Pidat tento SQL dotaz do oblbench';
$strBookmarkView = 'Jen zobrazit';
$strBrowseForeignValues = 'Projt hodnoty cizch kl';
$strBrowse = 'Projt';
$strBufferPoolActivity = 'Aktivita vyrovnvac pamti';
$strBufferPoolUsage = 'Vyuit vyrovnvac pamti';
$strBufferPool = 'Vyrovnvac pam';
$strBufferReadMissesInPercent = 'Vpadk pi ten v %';
$strBufferReadMisses = 'Vpadk pi ten';
$strBufferWriteWaits = 'ekn na zpis';
$strBufferWriteWaitsInPercent = 'ekn na zpis v %';
$strBulgarian = 'Bulhartina';
$strBusyPages = 'Zpracovvanch strkek';
$strBzError = 'phpMyAdminovi se nepodailo zkomprimovat vpis, protoe rozen pro kompresi bz2 je v&nbsp;tto verzi PHP chybn. Doporuujeme tuto kompresi vypnout (nastavit <code>$cfg[\'BZipDump\']</code> v&nbsp;nastavench phpMyAdmina na <code>FALSE</code>). Pokud chcete pouvat kompresi bz2, mli byste nainstalovat novj verzi PHP. Vce informac o&nbsp;tomto problmu je u popisu chyby %s.';
$strBzip = '"zabzipovno"';

$strCalendar = 'Kalend';
$strCannotLogin = 'Nepodailo se pihlen k MySQL serveru';
$strCantLoad = 'nelze nahrt rozen %s,<br />zkontrolujte prosm nastaven PHP';
$strCantLoadRecodeIconv = 'Nelze nahrt rozen iconv ani recode potebn pro pevod znakovch sad. Upravte nastaven PHP tak, aby umoovalo pout tyto rozen nebo vypnte pevod znakovch sad v&nbsp;phpMyAdminu.';
$strCantRenameIdxToPrimary = 'Index nemete pejmenovat na "PRIMARY"!';
$strCantUseRecodeIconv = 'Nelze pout funkce iconv ani libiconv ani recode_string, pestoe rozen jsou nahrna. Zkontrolujte nastaven PHP.';
$strCardinality = 'Mohutnost';
$strCarriage = 'Nvrat vozku (CR): \\r';
$strCaseInsensitive = 'nerozliovat velk a mal psmena';
$strCaseSensitive = 'rozliovat velk a mal psmena';
$strCentralEuropean = 'Stedn Evropa';
$strChangeCopyModeCopy = '... zachovat pvodnho uivatele.';
$strChangeCopyModeDeleteAndReload = ' ... smazat uivatele a pot znovu nast oprvnn.';
$strChangeCopyModeJustDelete = ' ... smazat pvodnho uivatele ze vech tabulek.';
$strChangeCopyModeRevoke = ' ... odebrat vechna oprvnn pvodnmu uivateli a pot ho smazat.';
$strChangeCopyMode = 'Vytvoit novho uivatele se stejnmi oprvnnmi a ...';
$strChangeCopyUser = 'Zmnit informace o&nbsp;uivateli / Koprovat uivatele';
$strChangeDisplay = 'Zvolte kter sloupce zobrazit';
$strChangePassword = 'Zmnit heslo';
$strChange = 'Zmnit';
$strCharsetOfFile = 'Znakov sada souboru:';
$strCharsetsAndCollations = 'Znakov sady a porovnvn';
$strCharsets = 'Znakov sady';
$strCharset = 'Znakov sada';
$strCheckAll = 'Zakrtnout ve';
$strCheckOverhead = 'Zakrtnout neoptimln';
$strCheckPrivsLong = 'Zkontrolovat oprvnn pro databzi &quot;%s&quot;.';
$strCheckPrivs = 'Zkontrolovat oprvnn';
$strCheckTable = 'Zkontrolovat tabulku';
$strChoosePage = 'Zvolte strnku, kterou chcete zmnit';
$strColComFeat = 'Zobrazuji komente sloupc';
$strCollation = 'Porovnvn';
$strColumnNames = 'Nzvy sloupc';
$strColumnPrivileges = 'Oprvnn pro jednotliv sloupce';
$strCommand = 'Pkaz';
$strCommentsForTable = 'KOMENTE PRO TABULKU';
$strComments = 'Komente';
$strCompatibleHashing = 'Kompatibiln s&nbsp;MySQL&nbsp;4.0';
$strCompleteInserts = 'pln inserty';
$strCompression = 'Komprese';
$strConfigFileError = 'phpMyAdmin nemohl nast konfiguran soubor!<br />Tato chyba me nastat, pokud v&nbsp;nm PHP najde chybu nebo neme tento soubor najt.<br />Po kliknut na nsledujc odkaz se PHP pokus pmo interpretovat tento soubor a zobraz informace o&nbsp;chyb, ke kter dolo. Pak opravte tuto chybu (nejastji se jedn o&nbsp;chybjc stednk).<br />Pokud zskte przdnou strnku, vechno je v&nbsp;podku.';
$strConfigureTableCoord = 'Prosm, nastavte souadnice pro tabulku %s';
$strConnectionError = 'Nepodailo se pipojit: chybn nastaven.';
$strConnections = 'Pipojen';
$strConstraintsForDumped = 'Omezen pro exportovan tabulky';
$strConstraintsForTable = 'Omezen pro tabulku';
$strCookiesRequired = 'Bhem tohoto kroku muste mt povoleny cookies.';
$strCopyDatabaseOK = 'Databze %s byla zkoprovna na %s';
$strCopy = 'Koprovat';
$strCopyTable = 'Koprovat tabulku do (databze<b>.</b>tabulka):';
$strCopyTableOK = 'Tabulka %s byla zkoprovna do %s.';
$strCopyTableSameNames = 'Nelze koprovat tabulku na sebe samu!';
$strCouldNotKill = 'phpMyAdminovi se nepodailo ukonit vlkno %s. Pravdpodobn jeho bh ji skonil.';
$strCreateDatabaseBeforeCopying = 'Vytvoit databzi ped koprovnm (CREATE DATABASE)';
$strCreateIndexTopic = 'Vytvoit nov index';
$strCreateIndex = 'Vytvoit index na&nbsp;%s&nbsp;sloupcch';
$strCreateNewDatabase = 'Vytvoit novou databzi';
$strCreateNewTable = 'Vytvoit novou tabulku v&nbsp;databzi %s';
$strCreatePage = 'Vytvoit novou strnku';
$strCreatePdfFeat = 'Vytven PDF';
$strCreate = 'Vytvoit';
$strCreationDates = 'Datum vytvoen, posledn zmny a kontroly';
$strCriteria = 'Podmnka';
$strCroatian = 'Chorvattina';
$strCSVOptions = 'Nastaven CSV exportu';
$strCyrillic = 'Cyrilika';
$strCzech = 'etina';
$strCzechSlovak = 'etina/Sloventina';

$strDanish = 'Dntina';
$strDatabase = 'Databze';
$strDatabaseEmpty = 'Jmno databze je przdn!';
$strDatabaseExportOptions = 'Nastaven exportu databz';
$strDatabaseHasBeenDropped = 'Databze %s byla zruena.';
$strDatabaseNoTable = 'Tato databze neobsahuje dn tabulky!';
$strDatabases = 'Databze';
$strDatabasesDropped = '%s databze byla spn zruena.';
$strDatabasesStatsDisable = 'Skrt podrobnosti';
$strDatabasesStatsEnable = 'Zobrazit podrobnosti';
$strDatabasesStatsHeavyTraffic = 'Poznmka: Zobrazen podrobnost o&nbsp;databzch me zpsobit znan zven provozu mezi webserverem a MySQL serverem.';
$strDatabasesStats = 'Statistiky databz';
$strData = 'Data';
$strDataDict = 'Datov slovnk';
$strDataOnly = ' Jen data';
$strDataPages = 'Strnek obshahujcch data';
$strDBComment = 'Koment k databzi: ';
$strDBCopy = 'Zkoprovat databzi na';
$strDBGContextID = 'Kontext ID';
$strDBGContext = 'Kontext';
$strDBGHits = 'Zsah';
$strDBGLine = 'dka';
$strDBGMaxTimeMs = 'Min. as, ms';
$strDBGMinTimeMs = 'Max. as, ms';
$strDBGModule = 'Modul';
$strDBGTimePerHitMs = 'as/Zsah, ms';
$strDBGTotalTimeMs = 'Celkov as, ms';
$strDbPrivileges = 'Oprvnn pro jednotliv databze';
$strDBRename = 'Pejmenovat databzi na';
$strDbSpecific = 'zvisl na databzi';
$strDefaultEngine = '%s je vchoz loit na tomto MySQL serveru.';
$strDefaultValueHelp = 'Vchoz hodnotu zadejte jen jednu hodnotu bez uvozovek a escapovn znak, napklad: a';
$strDefault = 'Vchoz';
$strDefragment = 'Defragmentovat tabulku';
$strDelayedInserts = 'Pouvat zpodn inserty';
$strDeleteAndFlushDescr = 'Toto je nejist een, ale natn oprvnn me trvat dlouho.';
$strDeleteAndFlush = 'Odstranit uivatele a znovunast oprvnn.';
$strDeleted = 'dek byl smazn';
$strDeletedRows = 'Smazan dky:';
$strDelete = 'Smazat';
$strDeleting = 'Odstrauji %s';
$strDelOld = 'Aktuln strnka se odkazuje na tabulky, kter ji neexistuj. Chcete odstranit tyto odkazy?';
$strDescending = 'Sestupn';
$strDescription = 'Popis';
$strDictionary = 'slovnk';
$strDirtyPages = 'Zmnnch strnek';
$strDisabled = 'Vypnuto';
$strDisableForeignChecks = 'Vypnout kontrolu cizch kl';
$strDisplayFeat = 'Zobrazen funkc';
$strDisplayOrder = 'Seadit podle:';
$strDisplayPDF = 'Zobrazit jako schma v&nbsp;PDF';
$strDoAQuery = 'Provst "dotaz podle pkladu" (zstupn znak: "%")';
$strDocu = 'Dokumentace';
$strDoYouReally = 'Opravdu si pejete vykonat pkaz';
$strDropDatabaseStrongWarning = 'Chystte se ZRUIT celou databzi!';
$strDrop = 'Odstranit';
$strDropSelectedDatabases = 'Zruit vybranou databzi';
$strDropUsersDb = 'Odstranit databze se stejnmi jmny jako uivatel.';
$strDumpingData = 'Vypisuji data pro tabulku';
$strDumpSaved = 'Vpis byl uloen do souboru %s.';
$strDumpXRows = 'Vypsat %s dk od %s.';
$strDynamic = 'dynamick';

$strEditPDFPages = 'Upravit PDF strnky';
$strEditPrivileges = 'Upravit oprvnn';
$strEdit = 'Upravit';
$strEffective = 'Efektivn';
$strEmptyResultSet = 'MySQL vrtil przdn vsledek (tj. nulov poet dk).';
$strEmpty = 'Vyprzdnit';
$strEnabled = 'Zapnuto';
$strEncloseInTransaction = 'Uzavt pkazy v&nbsp;transakci';
$strEndCut = 'KONEC VPISU';
$strEnd = 'Konec';
$strEndRaw = 'KONEC VPISU';
$strEngineAvailable = 'loit %s nen dostupn na tomto MySQL serveru.';
$strEngineDisabled = 'loit %s je vypnut na tomto MySQL serveru.';
$strEngines = 'loit';
$strEngineUnsupported = 'Tento MySQL server nepodporuje loit %s.';
$strEnglish = 'Anglicky';
$strEnglishPrivileges = 'Poznmka: nzvy oprvnn v&nbsp;MySQL jsou uvdny anglicky';
$strError = 'Chyba';
$strEscapeWildcards = 'Zstupn znaky _ a % by mly bt escapovny pomoc \, pokud je chcete pout jako znak';
$strEstonian = 'Estontina';
$strExcelEdition = 'Verze Excelu';
$strExcelOptions = 'Nastaven exportu do Excelu';
$strExecuteBookmarked = 'Spustit oblben dotaz';
$strExplain = 'Vysvtlit (EXPLAIN) SQL';
$strExport = 'Export';
$strExtendedInserts = 'Rozen inserty';
$strExtra = 'Extra';

$strFailedAttempts = 'Nepovedench pokus';
$strFieldHasBeenDropped = 'Sloupec %s byl odstrann';
$strFieldsEmpty = ' Nebyl zadn poet sloupc! ';
$strFieldsEnclosedBy = 'Nzvy sloupc uzaven do';
$strFieldsEscapedBy = 'Nzvy sloupc escapovny';
$strField = 'Sloupec';
$strFields = 'Sloupce';
$strFieldsTerminatedBy = 'Sloupce oddlen';
$strFileAlreadyExists = 'Soubor %s ji na serveru existuje, zmte jmno souboru, nebo zvolte pepsn souboru.';
$strFileCouldNotBeRead = 'Soubor nelze pest';
$strFileNameTemplateHelp = 'Pouijte __DB__ pro jmno databze, __TABLE__ pro jmno tabulky a jakkoliv parametry pro %sfunkci strftime%s pro vloen data. Ppona souboru bude automaticky pidna podle typu. Jakkoliv jin text bude zachovn.';
$strFileNameTemplateRemember = 'zapamatovat si hodnotu';
$strFileNameTemplate = 'Vzor pro jmno souboru';
$strFixed = 'pevn';
$strFlushPrivilegesNote = 'Poznmka: phpMyAdmin zskv oprvnn pmo z&nbsp;tabulek MySQL. Obsah tchto tabulek se me liit od oprvnn, kter server prv pouv, pokud byly tyto tabulky upravovny. V&nbsp;tomto ppad je vhodn provst %sznovunaten oprvnn%s ped pokraovnm.';
$strFlushTable = 'Vyprzdnit vyrovnvac pam pro tabulku ("FLUSH")';
$strFormat = 'Formt';
$strFormEmpty = 'Chybjc hodnota ve formuli!';
$strFreePages = 'Volnch strnek';
$strFullText = 'Cel texty';
$strFunction = 'Funkce';

$strGenBy = 'Vygeneroval';
$strGeneralRelationFeat = 'Obecn funkce relac';
$strGeneratePassword = 'Vytvoit heslo';
$strGenerate = 'Vytvoit';
$strGenTime = 'Vygenerovno';
$strGeorgian = 'Gruzntina';
$strGerman = 'Nmecky';
$strGlobal = 'globln';
$strGlobalPrivileges = 'Globln oprvnn';
$strGlobalValue = 'Globln hodnota';
$strGo = 'Prove';
$strGrantOption = 'Pidlovn';
$strGreek = 'etina';
$strGzip = '"zagzipovno"';

$strHasBeenAltered = 'byla zmnna.';
$strHasBeenCreated = 'byla vytvoena.';
$strHaveToShow = 'Muste zvolit alespo jeden sloupec, kter chcete zobrazit.';
$strHebrew = 'Hebrejtina';
$strHexForBinary = 'Binrn pole vypisovat estnctkov';
$strHome = 'Hlavn strana';
$strHomepageOfficial = 'Oficiln strnka phpMyAdmina';
$strHostEmpty = 'Jmno potae je przdn!';
$strHost = 'Pota';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Nastaven exportu pro Microsoft Excel 2000';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Nastaven exportu pro Microsoft Word 2000';
$strHungarian = 'Maartina';

$strIcelandic = 'Islandtina';
$strId = 'ID';
$strIdxFulltext = 'Fulltext';
$strIfYouWish = 'Pokud si pejete nathnout jen vybran sloupce z&nbsp;tabulky, napite je jako seznam sloupc oddlench rkou.';
$strIgnore = 'Ignorovat';
$strIgnoreInserts = 'Pout IGNORE';
$strIgnoringFile = 'Ignoruji soubor %s';
$strImportDocSQL = 'Importovat soubory docSQL';
$strImportFiles = 'Importovat soubory';
$strImportFinished = 'Import ukonen';
$strIndexes = 'Indexy';
$strIndexHasBeenDropped = 'Index %s byl odstrann';
$strIndex = 'Index';
$strIndexName = 'Jmno indexu&nbsp;:';
$strIndexType = 'Typ indexu&nbsp;:';
$strIndexWarningMultiple = 'Pro sloupec `%s` je vytvoeno vce index';
$strIndexWarningPrimary = 'Sloupec `%s` by neml bt zrove obsaen v&nbsp;PRIMARY a INDEX kli';
$strIndexWarningTable = 'Problmy s&nbsp;indexy v&nbsp;tabulce `%s`';
$strIndexWarningUnique = 'Sloupec `%s` by neml bt zrove obsaen v&nbsp;PRIMARY a UNIQUE kli';
$strInnoDBAutoextendIncrementDesc = 'Velikost o&nbsp;kterou je zvten soubor s&nbsp;daty, pokud je zaplnn.';
$strInnoDBAutoextendIncrement = 'Krok automatickho zvtovn';
$strInnoDBBufferPoolSizeDesc = 'Velikost vyrovnvac pamti, kterou InnoDB pouv pro cache dat a index tabulek.';
$strInnoDBBufferPoolSize = 'Velikost vyrovnvac pamti';
$strInnoDBDataFilePath = 'Soubor s&nbsp;daty';
$strInnoDBDataHomeDirDesc = 'Spolen st cesty pro vechny soubory obsahujc data InnoDB.';
$strInnoDBDataHomeDir = 'Domovsk adres pro data';
$strInnoDBPages = 'strnek';
$strInnodbStat = 'Stav InnoDB';
$strInsecureMySQL = 'Mte standardn nastaven hesla uivatele root v&nbsp;MySQL. Doporuujeme zmnit toto nastaven a tm podstatn zvit bezpenost Vaeho serveru.';
$strInsertAsNewRow = 'Vloit jako nov dek';
$strInsertBookmarkTitle = 'Prosm zadejte nzev oblben poloky';
$strInsertedRowId = 'Id vloenho dku:';
$strInsertedRows = 'Vloeno dk:';
$strInsertNewRow = 'Vloit nov dek';
$strInsertTextfiles = 'Vloit textov soubory do tabulky';
$strInsert = 'Vloit';
$strInstructions = 'Instrukce';
$strInternalNotNecessary = '* Intern relace nen potebn, pokud ji relace existuje v InnoDB.';
$strInternalRelations = 'Intern relace';
$strInUse = 'prv se pouv';

$strJapanese = 'Japontina';
$strJumpToDB = 'Na databzi &quot;%s&quot;.';
$strJustDeleteDescr = 'Odstrann uivatel stle budou mt pstup na server, dokud nebudou znovunatena oprvnn.';
$strJustDelete = 'Jen odstranit uivatele z tabulek s oprvnnmi.';

$strKeepPass = 'Nemnit heslo';
$strKeyname = 'Klov nzev';
$strKill = 'Ukonit';
$strKorean = 'Korejtina';

$strLandscape = 'Na ku';
$strLatchedPages = 'Zamench strnek';
$strLatexCaption = 'Titulek tabulky';
$strLatexContent = 'Obsah tabulky __TABLE__';
$strLatexContinuedCaption = 'Titulek pokraovn tabulky';
$strLatexContinued = '(pokraovn)';
$strLatexIncludeCaption = 'Pout titulek tabulky';
$strLatexLabel = 'Nvst';
$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'Nastaven exportu do LaTeXu';
$strLatexStructure = 'Struktura tabulky __TABLE__';
$strLatvian = 'Lotytina';
$strLengthSet = 'Dlka/Mnoina*';
$strLimitNumRows = 'zznam na strnku';
$strLineFeed = 'Ukonen dk: \\n';
$strLinesTerminatedBy = 'dky ukonen';
$strLinkNotFound = 'Odkaz nenalezen';
$strLinksTo = 'Odkazuje na';
$strLithuanian = 'Litevtina';
$strLoadExplanation = 'Automaticky jsou zvoleny nejvhodnj parametry, pokud toto nastaven sele, mete zkusit druhou monost.';
$strLoadMethod = 'Parametry pro pkaz LOAD';
$strLocalhost = 'Lokln';
$strLocationTextfile = 'textov soubor';
$strLoginInformation = 'Pihlaovn';
$strLogin = 'Pihlen';
$strLogout = 'Odhlsit se';
$strLogPassword = 'Heslo:';
$strLogServer = 'Server';
$strLogUsername = 'Jmno:';
$strLongOperation = 'Tato operace me trvat velmi dlouho. Chcete je pesto provst?';

$strMaximumSize = 'Maximln velikost: %s%s';
$strMbExtensionMissing = 'Rozen mbstring pro PHP nebylo nalezeno a zd se, e povte vcebajtovou znakovou sadu. Bez rozen mbstring neum phpMyAdmin sprvn rozdlovat etzce a proto to me mt neekan nsledky.';
$strMbOverloadWarning = 'V&nbsp;nastaven PHP mte zapnuto mbstring.func_overload. Toto nastaven nen kompatibiln s&nbsp;phpMyAdminem a me zpsobit pokozen dat!';
$strMIME_available_mime = 'Dostupn MIME typy';
$strMIME_available_transform = 'Dostupn transformace';
$strMIME_description = 'Popis';
$strMIME_MIMEtype = 'MIME typ';
$strMIME_nodescription = 'Pro tuto transformaci nen dostupn dn popis.<br />Zeptejte se autora co %s dl.';
$strMIME_transformation_note = 'Pro seznam dostupnch parametr transformac a jejich MIME typ kliknte na %spopisy transformac%s';
$strMIME_transformation_options_note = 'Zadejte parametry transformac v&nbsp;nsledujcm tvaru: \'a\',\'b\',\'c\'...<br />Pokud potebujete pout zptn lomtko ("\") nebo jednoduch uvozovky ("\'") mezi tmito hodnotami, vlote ped n zptn lomtko (napklad \'\\\\xyz\' nebo \'a\\\'b\').';
$strMIME_transformation_options = 'Parametry transformace';
$strMIME_transformation = 'Transformace pi prohlen';
$strMIMETypesForTable = 'MIME TYPY PRO TABULKU';
$strMIME_without = 'MIME typy zobrazen kurzvou nemaj vlastn transforman funkci';
$strModifications = 'Zmny byly uloeny';
$strModifyIndexTopic = 'Upravit index';
$strModify = 'pravy';
$strMoreStatusVars = 'Dal informace o&nbsp;stavu';
$strMoveTableOK = 'Tabulka %s byla pesunuta do %s.';
$strMoveTable = 'Pesunout tabulku do (databze<b>.</b>tabulka):';
$strMoveTableSameNames = 'Nelze pesunout tabulku na sebe samu!';
$strMultilingual = 'mnohojazyn';
$strMustSelectFile = 'Zvolte soubor, kter chcete vloit.';
$strMyISAMDataPointerSizeDesc = 'Vchoz velikost ukazatele v&nbsp;bajtech, kter bude pouita pro vytven MyISAM tabulek, pokud nen uvedeno MAX_ROWS.';
$strMyISAMDataPointerSize = 'Velikost ukazatele na data';
$strMyISAMMaxExtraSortFileSizeDesc = 'Pokud by byl soubor pro vytven MyISAM indexu byl vt ne zde uveden hodnota, pouije se pomalej metoda cache kl.';
$strMyISAMMaxExtraSortFileSize = 'Maximln velikost doasnch soubor pi vytven indexu';
$strMyISAMMaxSortFileSizeDesc = 'Maximln velikost doasnch soubor, kter sm MySQL pout pi obnov indexu (pi REPAIR TABLE, ALTER TABLE nebo LOAD DATA INFILE).';
$strMyISAMMaxSortFileSize = 'Maximln velikost doasnch soubor pro azen';
$strMyISAMRecoverOptions = 'Automatick reim obnovy';
$strMyISAMRecoverOptionsDesc = 'Reim automatick obnovy pokozench MyISAM tabulek. Nastavuje se parametrem --myisam-recover pi spoutn serveru.';
$strMyISAMRepairThreadsDesc = 'Pokud je tato hodnota vt ne 1, indexy v&nbsp;MyISAM tabulkch jsou vytveny paralelen (kad index vlastnm threadem) pi obnov nebo azen.';
$strMyISAMRepairThreads = 'Thread pro opravovn';
$strMyISAMSortBufferSizeDesc = 'Pam, kter je alokovna pi azen MyISAM index bhem jejich vytven nebo opravovn.';
$strMyISAMSortBufferSize = 'Velikost pamti pro azen';
$strMySQLCharset = 'Znakov sada v&nbsp;MySQL';
$strMySQLConnectionCollation = 'Znakov sada pipojen k&nbsp;MySQL';
$strMySQLReloaded = 'MySQL znovu nateno.';
$strMySQLSaid = 'MySQL hls: ';
$strMySQLServerProcess = 'MySQL %pma_s1% bc na serveru %pma_s2%, uivatel pihlen jako %pma_s3%';
$strMySQLShowProcess = 'Zobrazit procesy';
$strMySQLShowStatus = 'Ukzat informace o&nbsp;bhu MySQL';
$strMySQLShowVars = 'Ukzat systmov promnn MySQL';

$strName = 'Nzev';
$strNeedPrimaryKey = 'Pro tuto tabulku byste mli definovat primrn kl.';
$strNext = 'Dal';
$strNoActivity = 'Byli jste pli dlouho neaktivn (dle ne %s sekund), prosm pihlaste se znovu';
$strNoDatabasesSelected = 'Nebyla vybrna dn databze.';
$strNoDatabases = 'dn databze';
$strNoDescription = 'dn popisek';
$strNoDetailsForEngine = 'Nejsou dostupn podrobnj informace o tomto loiti.';
$strNoDropDatabases = 'Pkaz "DROP DATABASE" je vypnut.';
$strNoExplain = 'Bez vysvtlen (EXPLAIN) SQL';
$strNoFrames = 'phpMyAdmin se lpe pouv v&nbsp;prohlei podporujcm rmy ("FRAME").';
$strNoIndexPartsDefined = 'dn st indexu nebyla definovna!';
$strNoIndex = 'dn index nebyl definovn!';
$strNoModification = 'dn zmna';
$strNo = 'Ne';
$strNone = 'dn';
$strNoOptions = 'Tento formt nem dn nastaven';
$strNoPassword = 'dn heslo';
$strNoPermission = 'Web server nem oprvnn uloit vpis do souboru %s.';
$strNoPhp = 'Bez PHP kdu';
$strNoPrivileges = 'Nemte oprvnn';
$strNoQuery = 'dn SQL dotaz!';
$strNoRights = 'Nemte dostaten prva na proveden tto akce!';
$strNoRowsSelected = 'Nebyl vybrn dn dek';
$strNoSpace = 'Nedostatek msta pro uloen souboru %s.';
$strNoTablesFound = 'V&nbsp;databzi nebyla nalezena dn tabulka.';
$strNoThemeSupport = 'Nen podporovna zmna tmatu, zkontrolujte nastaven a tmata v adresi %s.';
$strNotNumber = 'Nebylo zadno slo!';
$strNotOK = 'nen v podku';
$strNotSet = '<b>%s</b> tabulka nenalezena nebo nen nastavena v&nbsp;%s';
$strNotValidNumber = ' nen platn slo dku!';
$strNoUsersFound = 'dn uivatel nenalezen.';
$strNoValidateSQL = 'Bez kontroly SQL';
$strNull = 'Nulov';
$strNumSearchResultsInTable = '%s odpovdajc(ch) zznam() v&nbsp;tabulce <i>%s</i>';
$strNumSearchResultsTotal = '<b>Celkem:</b> <i>%s</i> odpovdajc(ch) zznam()';
$strNumTables = 'Tabulek';

$strOftenQuotation = 'asto uvozujc znaky. Voliteln znamen, e pouze poloky u kterch je to nutn (obvykle typu CHAR a VARCHAR) jsou uzaveny do uzavracch znak.';
$strOK = 'OK';
$strOperations = 'pravy';
$strOperator = 'Opertor';
$strOptimizeTable = 'Optimalizovat tabulku';
$strOptionalControls = 'Voliteln. Uruje, jak zapisovat nebo st speciln znaky.';
$strOptionally = 'Voliteln';
$strOr = 'nebo';
$strOverhead = 'Navc';
$strOverwriteExisting = 'Pepsat existujc soubor(y)';

$strPageNumber = 'Strana slo:';
$strPagesToBeFlushed = 'Strnek urench k uvolnn';
$strPaperSize = 'Velikost strnky';
$strPartialText = 'Zkrcen texty';
$strPasswordChanged = 'Heslo pro %s bylo spn zmnno.';
$strPasswordEmpty = 'Heslo je przdn!';
$strPasswordHashing = 'Haovac funkce pro heslo';
$strPassword = 'Heslo';
$strPasswordNotSame = 'Hesla nejsou stejn!';
$strPdfDbSchema = 'Schma databze "%s" - Strana %s';
$strPdfInvalidTblName = 'Tabulka "%s" neexistuje!';
$strPdfNoTables = 'dn tabulky';
$strPerHour = 'za hodinu';
$strPerMinute = 'za minutu';
$strPerSecond = 'za sekundu';
$strPersian = 'Pertina';
$strPhoneBook = 'adres';
$strPHP40203 = 'Pouvte PHP 4.2.3, kter m zvanou chybu pi prci s&nbsp;vcebajtovmi znaky (mbstring), jedn se o&nbsp;chybu PHP slo 19404. Nedoporuujeme pouvat tuto verzi PHP s&nbsp;phpMyAdminem.';
$strPHPVersion = 'Verze PHP';
$strPhp = 'Zobrazit PHP kd';
$strPmaDocumentation = 'Dokumentace phpMyAdmina';
$strPmaUriError = 'Parametr <tt>$cfg[\'PmaAbsoluteUri\']</tt> MUS bt nastaven v&nbsp;konfiguranm souboru!';
$strPolish = 'Poltina';
$strPortrait = 'Na vku';
$strPos1 = 'Zatek';
$strPrevious = 'Pedchoz';
$strPrimaryKeyHasBeenDropped = 'Primrn kl byl odstrann';
$strPrimaryKeyName = 'Jmno primrnho kle mus bt "PRIMARY"!';
$strPrimaryKeyWarning = '("PRIMARY" <b>mus</b> bt jmno <b>pouze</b> primrnho kle!)';
$strPrimary = 'Primrn';
$strPrintViewFull = 'Nhled k vytitn (s&nbsp;kompletnmi texty)';
$strPrintView = 'Nhled k vytitn';
$strPrint = 'Vytisknout';
$strPrivDescAllPrivileges = 'Vechna oprvnn krom GRANT.';
$strPrivDescAlterDb = 'Umouje mnit strukturu existujcch tabulek a vchoz znakov sady a azen databz.';
$strPrivDescAlterRoutine = 'Umouje mnit a ruit uloen procedury.';
$strPrivDescAlter = 'Umouje mnit strukturu existujcch tabulek.';
$strPrivDescCreateDb = 'Umouje vytvet nov databze a tabulky.';
$strPrivDescCreateRoutine = 'Umouje vytvet uloen procedury.';
$strPrivDescCreateTbl = 'Umouje vytvet nov tabulky.';
$strPrivDescCreateTmpTable = 'Umouje vytvet doasn tabulky.';
$strPrivDescCreateUser = 'Umouje vytvet, ruit a pejmenovvat ty uivatel.';
$strPrivDescCreateView = 'Umouje vytvet nov pohledy.';
$strPrivDescDelete = 'Umouje mazat data.';
$strPrivDescDropDb = 'Umouje odstranit databze a tabulky.';
$strPrivDescDropTbl = 'Umouje odstranit tabulky.';
$strPrivDescExecute5 = 'Umouje spoutt uloen procedury.';
$strPrivDescExecute = 'Umouje spoutt uloen procedury. V&nbsp;tto verzi MySQL se nepouv.';
$strPrivDescFile = 'Umouje importovat a exportovat data z/do soubor na serveru.';
$strPrivDescGrant = 'Umouje pidvat uivatele a oprvnn bez znovunatn tabulek s&nbsp;oprvnnmi.';
$strPrivDescIndex = 'Umouje vytvet a ruit indexy.';
$strPrivDescInsert = 'Umouje vkldat a pepisovat data.';
$strPrivDescLockTables = 'Umouje zamknout tabulku pro aktuln thread.';
$strPrivDescMaxConnections = 'Omez poet novch pipojen, kter me uivatel vytvoit za hodinu.';
$strPrivDescMaxQuestions = 'Omez, kolik dotaz me uivatel odeslat serveru za hodinu.';
$strPrivDescMaxUpdates = 'Omez, kolik dotaz mncch njakou tabulku nebo databzi me uivatel spustit za hodinu.';
$strPrivDescProcess3 = 'Umouje ukonit procesy jinm uivatelm.';
$strPrivDescProcess4 = 'Umouje vidt cel dotazy v&nbsp;seznamu proces.';
$strPrivDescReferences = 'Nem dn vliv v&nbsp;tto verzi MySQL.';
$strPrivDescReload = 'Umouje znovunaten nastaven a vyprzdnn vyrovnvacch pamt MySQL serveru.';
$strPrivDescReplClient = 'Umon uivateli zjistit, kde je hlavn / pomocn server.';
$strPrivDescReplSlave = 'Potebn pro replikaci pomocnch server.';
$strPrivDescSelect = 'Umouje vybrat data.';
$strPrivDescShowDb = 'Umouje pstup k&nbsp;plnmu seznamu databz.';
$strPrivDescShowView = 'Umouje sputn dotazu SHOW CREATE VIEW.';
$strPrivDescShutdown = 'Umouje vypnout server.';
$strPrivDescSuper = 'Umouje pipojen, i kdy je dosaen maximln poet pipojen. Potebn pro vtinu operac pro sprvu serveru jako nastavovn globlnch promnnch a zabjen thread jinch uivatel.';
$strPrivDescUpdate = 'Umouje mnit data.';
$strPrivDescUsage = 'dn oprvnn.';
$strPrivileges = 'Oprvnn';
$strPrivilegesReloaded = 'Oprvnn byla znovunatena spn.';
$strProcesslist = 'Seznam proces';
$strPutColNames = 'Pidat jmna sloupc na prvn dek';

$strQBEDel = 'smazat';
$strQBE = 'Dotaz';
$strQBEIns = 'pidat';
$strQueryFrame = 'SQL okno';
$strQueryOnDb = 'SQL dotaz na databzi <b>%s</b>:';
$strQuerySQLHistory = 'SQL historie';
$strQueryStatistics = '<b>Statistika dotaz</b>: Od sputn bylo serveru poslno %s dotaz.';
$strQueryTime = 'Dotaz zabral %01.4f sekund';
$strQueryType = 'Typ dotazu';
$strQueryWindowLock = 'Nepepisovat tento dotaz z&nbsp;hlavnho okna';

$strReadRequests = 'Poadavk na zpis';
$strReceived = 'Pijato';
$strRecords = 'Zznam';
$strReferentialIntegrity = 'Zkontrolovat integritu odkaz:';
$strRefresh = 'Obnovit';
$strRelationalSchema = 'Relan schma';
$strRelationNotWorking = 'Nkter z&nbsp;rozench funkc phpMyAdmina nelze pouvat. %sZde%s zjistte pro.';
$strRelationsForTable = 'RELACE PRO TABULKU';
$strRelations = 'Relace';
$strRelationView = 'Zobrazit relace';
$strReloadFailed = 'Znovunaten MySQL selhalo.';
$strReloadingThePrivileges = 'Znovunatm oprvnn';
$strReloadMySQL = 'Znovunaten MySQL';
$strRemoveSelectedUsers = 'Odstranit vybran uivatele';
$strRenameDatabaseOK = 'Databze %s byla pejmenovna na %s';
$strRenameTableOK = 'Tabulka %s byla pejmenovna na %s';
$strRenameTable = 'Pejmenovat tabulku na';
$strRepairTable = 'Opravit tabulku';
$strReplaceNULLBy = 'Nahradit NULL hodnoty';
$strReplace = 'Pepsat';
$strReplaceTable = 'Pepsat data tabulky souborem';
$strReset = 'Pvodn';
$strResourceLimits = 'Omezen zdroj';
$strReType = 'Heslo znovu';
$strRevokeAndDeleteDescr = 'Uivatel budou mt oprvnn "USAGE" (pouvn), dokud nebudou znovunatena oprvnn.';
$strRevokeAndDelete = 'Odebrat uivatelm veker oprvnn a pot je odstranit z tabulek.';
$strRevokeMessage = 'Byla zruena prva pro %s';
$strRevoke = 'Zruit';
$strRomanian = 'Rumuntina';
$strRoutines = 'Procedury';
$strRowLength = 'Dlka dku';
$strRowsFrom = 'dk zanajc od';
$strRowSize = ' Velikost dku ';
$strRowsModeFlippedHorizontal = 'vodorovnm (otoen hlaviky)';
$strRowsModeHorizontal = 'vodorovnm';
$strRowsModeOptions = 've %s reimu a opakovat hlaviky po %s dcch.';
$strRowsModeVertical = 'svislm';
$strRows = 'dk';
$strRowsStatistic = 'Statistika dk';
$strRunning = 'na %s';
$strRunQuery = 'Provst dotaz';
$strRunSQLQuery = 'Spustit SQL dotaz(y) na databzi %s';
$strRussian = 'Rutina';

$strSaveOnServer = 'Uloit na serveru v adresi %s';
$strSave = 'Ulo';
$strScaleFactorSmall = 'Mtko je pli mal, aby se schma velo na jednu strnku';
$strSearchFormTitle = 'Vyhledvn v&nbsp;databzi';
$strSearchInTables = 'V&nbsp;tabulkch:';
$strSearchNeedle = 'Slova nebo hodnoty, kter chcete vyhledat (zstupn znak: "%"):';
$strSearchOption1 = 'alespo jedno ze slov';
$strSearchOption2 = 'vechna slova';
$strSearchOption3 = 'pesnou frzi';
$strSearchOption4 = 'jako regulrn vraz';
$strSearchResultsFor = 'Vsledky vyhledvn pro "<i>%s</i>" %s:';
$strSearchType = 'Najt:';
$strSearch = 'Vyhledvn';
$strSecretRequired = 'Nastavte kl pro ifrovn cookies (blowfish_secret) v&nbsp;konfiguranm souboru (config.inc.php).';
$strSelectADb = 'Prosm vyberte databzi';
$strSelectAll = 'Vybrat ve';
$strSelectBinaryLog = 'Zvolte binrn log pro zobrazen';
$strSelectFields = 'Zvolte sloupec (alespo jeden):';
$strSelectNumRows = 'v&nbsp;dotazu';
$strSelectTables = 'Vybrat tabulky';
$strSend = 'Do souboru';
$strSent = 'Odeslno';
$strServerChoice = 'Vbr serveru';
$strServerNotResponding = 'Server neodpovd';
$strServer = 'Server';
$strServerStatus = 'Stav serveru';
$strServerStatusUptime = 'Tento MySQL server b %s. as sputn: %s.';
$strServerTabProcesslist = 'Procesy';
$strServerTabVariables = 'Promnn';
$strServerTrafficNotes = '<b>Provoz serveru</b>: Informace o&nbsp;sovm provozu MySQL serveru od jeho sputn.';
$strServerVars = 'Promnn a nastaven serveru';
$strServerVersion = 'Verze MySQL';
$strSessionValue = 'Hodnota sezen';
$strSetEnumVal = 'Pokud je sloupec typu "enum" nebo "set", zadvejte hodnoty v&nbsp;nsledujcm formtu: \'a\',\'b\',\'c\'...<br />Pokud potebujete zadat zptn lomtko ("\") nebo jednoduch uvozovky ("\'") mezi tmito hodnotami, napite ped n zptn lomtko (pklad: \'\\\\xyz\' nebo \'a\\\'b\').';
$strShowAll = 'Zobrazit ve';
$strShowColor = 'Barevn ipky';
$strShowDatadictAs = 'Formt datovho slovnku';
$strShowFullQueries = 'Zobrazit cel dotazy';
$strShowGrid = 'Zobrazit mku';
$strShowingRecords = 'Zobrazeny zznamy';
$strShowPHPInfo = 'Zobrazit informace o&nbsp;PHP';
$strShowTableDimension = 'Rozmry tabulek';
$strShowTables = 'Zobrazit tabulky';
$strShowThisQuery = 'Zobrazit zde tento dotaz znovu';
$strShow = 'Zobrazit';
$strSimplifiedChinese = 'Zjednoduen ntina';
$strSingly = '(po jednom)';
$strSize = 'Velikost';
$strSlovak = 'Sloventina';
$strSlovenian = 'Slovintina';
$strSocketProblem = '(nebo nen spvn nastaven lokln socket MySQL serveru)';
$strSortByKey = 'Setdit podle kle';
$strSort = 'adit';
$strSpaceUsage = 'Vyuit msta';
$strSpanish = 'panltina';
$strSplitWordsWithSpace = 'Slova jsou oddlena mezerou (" ").';
$strSQLExportCompatibility = 'Kompatibilita SQL exportu';
$strSQLExportType = 'Typ vytvoench dotaz';
$strSQLOptions = 'Nastaven SQL exportu';
$strSQLParserBugMessage = 'Je mon, e jste nali chybu v&nbsp;SQL parseru. Prosm prozkoumejte podrobn SQL dotaz, pedevm jestli jsou sprvn uvozovky a jestli nejsou prohzen. Dal monost selhn je pokud nahrvte soubor s&nbsp;binrnmi daty nezapsanmi v&nbsp;uvozovkch. Mete tak vyzkouet pkazovou dku MySQL. Ne uveden vstup z&nbsp;MySQL serveru (pokud je njak) Vm tak me pomoci pi zkoumn problmu. Pokud stle mte problmy nebo pokud SQL parser ohls chybu u dotazu, kter na pkazov dce funguje, prosm pokuste se zredukovat dotaz na co nejmen, ve kterm se problm jet vyskytne, a ohlaste chybu na strnkch phpMyAdmina spolu se sekc VPIS uvedenou ne:';
$strSQLParserUserError = 'Pravdpodobn mte v&nbsp;SQL dotazu chybu. Ne uveden vstup MySQL serveru (pokud je njak) Vm tak me pomoci pi zkoumn problmu';
$strSQLQuery = 'SQL-dotaz';
$strSQLResult = 'Vsledek SQL dotazu';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'Chybn identifiktor';
$strSQPBugUnclosedQuote = 'Neuzaven uvozovky';
$strSQPBugUnknownPunctuation = 'Neznm interpunkn znamnko';
$strStatCheckTime = 'Posledn kontrola';
$strStatCreateTime = 'Vytvoen';
$strStatement = 'daj';
$strStatUpdateTime = 'Posledn zmna';
$strStatus = 'Stav';
$strStorageEngines = 'loit';
$strStorageEngine = 'loit';
$strStrucCSV = 'CSV';
$strStrucData = 'Strukturu a data';
$strStrucDrop = 'Pidat DROP TABLE';
$strStrucExcelCSV = 'CSV pro MS Excel';
$strStrucNativeExcel = 'Nativn formt MS Excelu';
$strStrucOnly = 'Pouze strukturu';
$strStructPropose = 'Navrhnout strukturu tabulky';
$strStructure = 'Struktura';
$strSubmit = 'Odeli';
$strSuccess = 'V SQL-dotaz byl spn vykonn';
$strSum = 'Celkem';
$strSwedish = 'vdtina';
$strSwitchToDatabase = 'Pepnout na zkoprovanou databzi';
$strSwitchToTable = 'Pepnout na zkoprovanou tabulku';

$strTableComments = 'Koment k tabulce';
$strTableEmpty = 'Jmno tabulky je przdn!';
$strTableHasBeenDropped = 'Tabulka %s byla odstranna';
$strTableHasBeenEmptied = 'Tabulka %s byla vyprzdnna';
$strTableHasBeenFlushed = 'Vyrovnvac pam pro tabulku %s byla vyprzdnna';
$strTableMaintenance = ' drba tabulky ';
$strTableOfContents = 'Obsah';
$strTableOptions = 'Parametry tabulky';
$strTables = '%s tabulek';
$strTableStructure = 'Struktura tabulky';
$strTable = 'Tabulka';
$strTableType = 'Typ tabulky';
$strTakeIt = 'zvolit';
$strTblPrivileges = 'Oprvnn pro jednotliv tabulky';
$strTextAreaLength = 'Tento sloupec mon nepjde <br />(kvli dlce) upravit ';
$strThai = 'Thajtina';
$strTheContent = 'Obsah souboru byl vloen';
$strTheContents = 'Obsah souboru pepe obsah zvolen tabulky v&nbsp;tch dcch, kde je stejn primrn nebo uniktn kl.';
$strTheme = 'Vzhled';
$strTheTerminator = 'Sloupce jsou oddleny tmto znakem.';
$strThisHost = 'Tento pota';
$strThisNotDirectory = 'Nebyl zadn adres';
$strThreadSuccessfullyKilled = 'Vlkno %s bylo spn zabito.';
$strTime = 'as';
$strToggleScratchboard = 'Zobrazit grafick nvrh';
$strTotal = 'celkem';
$strTotalUC = 'Celkem';
$strTraditionalChinese = 'Tradin ntina';
$strTraditionalSpanish = 'Tradin panltina';
$strTraffic = 'Provoz';
$strTransformation_application_octetstream__download = 'Zobraz odkaz na sthnut dat. Prvn parametr je jmno souboru, druh jmno sloupce v tabulce obsahujc jmno souboru. Pokud zadte druh parametr, prvn mus bt przdn.';
$strTransformation_application_octetstream__hex = 'Zobraz data estnctkov.';
$strTransformation_image_jpeg__inline = 'Zobraz nhled obrzku s&nbsp;odkazem na obrzek; parametry ka a vka v&nbsp;bodech (pomr stran obrzku zstane zachovn)';
$strTransformation_image_jpeg__link = 'Zobraz odkaz na obrzek (napklad sthnut pole blob).';
$strTransformation_image_png__inline = 'Viz image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Zobraz datum nebo as (TIME, TIMESTAMP a DATETIME) podle mstnho nastaven. Prvn parametr je posun (v&nbsp;hodinch), kter bude pidn k&nbsp;asu (vchoz je 0). Druh parametr je formtovac etzec pro funkci strftime().';
$strTransformation_text_plain__external = 'JEN PRO LINUX: Spust extern program, na jeho standardn vstup pole obsah pole a zobraz vstup programu. Vchoz je program Tidy, kter pkn zformtuje HTML. Z&nbsp;bezpenostnch dvod muste jmna povolench program zapsat do souboru libraries/transformations/text_plain__external.inc.php. Prvn parametr je slo programu, kter m bt sputn a druh parametr udv parametry tohoto programu. Tet parametr uruje, zda maj bt ve vstupu nahrazeny HTML entity (nap. pro zobrazen zdrojovho kdu HTML) (vchoz je 1, tedy pevdt na entity), tvrt (pi nastaven na 1) zajist pidn parametru NOWRAP k&nbsp;vypisovanmu textu, m se zachov formtovn (vchoz je 1).';
$strTransformation_text_plain__formatted = 'Zachov pvodn formtovn sloupce, tak jak je uloen v&nbsp;databzi.';
$strTransformation_text_plain__imagelink = 'Zobraz obrzek a odkaz z&nbsp;pole obsahujcho odkaz na obrzek. Prvn parametr je prefix URL (napklad "http://mojedomena.cz/"), druh a tet uruje ku a vku obrzku.';
$strTransformation_text_plain__link = 'Zobraz odkaz z&nbsp;pole obsahujcho odkaz. Prvn parametr je prefix URL (napklad "http://mojedomena.cz/"), druh text odkazu.';
$strTransformation_text_plain__substr = 'Zobraz jen st textu. Prvn parametr je posun od zatku (vchoz je 0) a druh uruje dlku textu, kter se m zobrazit, pokud nen uveden, bude zobrazen zbytek textu. Tet parametr uruje, jak text m bt pidn za zkrcen text (vchoz je ...).';
$strTruncateQueries = 'Zobrazit zkrcen dotazy';
$strTurkish = 'Turecky';
$strType = 'Typ';

$strUkrainian = 'Ukrajintina';
$strUncheckAll = 'Odkrtnout ve';
$strUnicode = 'Unicode';
$strUnique = 'Uniktn';
$strUnknown = 'neznm';
$strUnselectAll = 'Odznait ve';
$strUpdatePrivMessage = 'Byla aktualizovna oprvnn pro %s.';
$strUpdateProfileMessage = 'Pstup byl zmnn.';
$strUpdateQuery = 'Aktualizovat dotaz';
$strUpdComTab = 'Podvejte se prosm do dokumentace, jak aktualizovat tabulku s&nbsp;informacemi o&nbsp;sloupcch (tabulka column_comments)';
$strUpgrade = 'Mli byste aktualizovat %s na verzi %s nebo vy.';
$strUsage = 'Pouv';
$strUseBackquotes = 'Pout zptn uvozovky u&nbsp;jmen tabulek a sloupc';
$strUseHostTable = 'Pout tabulku s&nbsp;potai';
$strUserAlreadyExists = 'Uivatel %s ji existuje!';
$strUserEmpty = 'Jmno uivatele je przdn!';
$strUserName = 'Jmno uivatele';
$strUserNotFound = 'Zvolen uivatel nebyl nalezen v&nbsp;tabulce oprvnn.';
$strUserOverview = 'Pehled uivatel';
$strUsersDeleted = 'Vybran uivatel byli spn odstranni.';
$strUsersHavingAccessToDb = 'Uivatel majc pstup k&nbsp;&quot;%s&quot;';
$strUser = 'Uivatel';
$strUseTabKey = 'Pouijte klvesu TAB pro pohyb mezi hodnotami nebo CTRL+ipky po pohyb vemi smry.';
$strUseTables = 'Pout tabulky';
$strUseTextField = 'Pout textov pole';
$strUseThisValue = 'Pout tuto hodnotu';

$strValidateSQL = 'Zkontrolovat SQL';
$strValidatorError = 'SQL validtor nemohl bt inicializovn. Prosm zkontrolujte, jestli mte poadovan rozen PHP, kter jsou uvedena v&nbsp;%sdokumentaci%s.';
$strValue = 'Hodnota';
$strVar = 'Promnn';
$strVersionInformation = 'Informace o&nbsp;verzi';
$strViewDumpDatabases = 'Export databz';
$strViewDumpDB = 'Export databze';
$strViewDump = 'Export tabulky';
$strViewHasBeenDropped = 'Pohled %s byl odstrann';
$strView = 'Pohled';

$strWebServerUploadDirectoryError = 'Adres uren pro upload soubor nemohl bt oteven';
$strWebServerUploadDirectory = 'soubor z&nbsp;adrese pro upload';
$strWelcome = 'Vtejte v&nbsp;%s';
$strWestEuropean = 'Zpadn Evropa';
$strWildcard = 'maska';
$strWindowNotFound = 'Clov okno prohlee nemohlo bt aktualizovno. Mon jste zavel rodiovsk okno, nebo prohle blokuje operace mezi okny z dvodu bezpenostnch nastaven.';
$strWithChecked = 'Zakrtnut:';
$strWriteRequests = 'Poadavk na ten';
$strWritingCommentNotPossible = 'Nelze zapsat koment';
$strWritingRelationNotPossible = 'Nelze zapsat relaci';
$strWrongUser = 'patn uivatelsk jmno nebo heslo. Pstup odepen.';

$strXML = 'XML';

$strYes = 'Ano';

$strZeroRemovesTheLimit = 'Poznmka: Nastaven tchto parametr na 0 (nulu) odstran omezen.';
$strZip = '"zazipovno"';

?>
